==> apache-inlong-1.11.0-src.tar.gz: apache-inlong-1.11.0/inlong-sort/sort-formats/format-row/format-csv/src/main/java/org/apache/inlong/sort/formats/csv/CsvFormatBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.csv;

import org.apache.inlong.sort.formats.base.TextFormatBuilder;
import org.apache.inlong.sort.formats.common.RowFormatInfo;

import org.apache.flink.table.descriptors.DescriptorProperties;

import static org.apache.inlong.sort.formats.base.TableFormatConstants.DEFAULT_DELIMITER;
import static org.apache.inlong.sort.formats.base.TableFormatConstants.FORMAT_DELIMITER;

/**
 * The builder for the serializers and deserializers for csv formats.
 */
public abstract class CsvFormatBuilder<T extends CsvFormatBuilder> extends TextFormatBuilder<T> {

    protected char delimiter = DEFAULT_DELIMITER;

    public CsvFormatBuilder(RowFormatInfo rowFormatInfo) {
        super(rowFormatInfo);
    }

    @SuppressWarnings("unchecked")
    public T setDelimiter(Character delimiter) {
        this.delimiter = delimiter;
        return (T) this;
    }

    @SuppressWarnings("unchecked")
    @Override
    public T configure(DescriptorProperties descriptorProperties) {
        super.configure(descriptorProperties);

        descriptorProperties.getOptionalCharacter(FORMAT_DELIMITER)
                .ifPresent(this::setDelimiter);

        return (T) this;
    }
}

==> apache-inlong-2.3.0-src.tar.gz: apache-inlong-2.3.0/inlong-sort/sort-formats/format-row/format-csv/src/main/java/org/apache/inlong/sort/formats/csv/CsvFormatBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.csv;

import org.apache.inlong.common.pojo.sort.dataflow.field.format.RowFormatInfo;
import org.apache.inlong.sort.formats.base.TextFormatBuilder;

import org.apache.flink.table.descriptors.DescriptorProperties;

import static org.apache.inlong.sort.formats.base.TableFormatConstants.DEFAULT_DELIMITER;
import static org.apache.inlong.sort.formats.base.TableFormatConstants.FORMAT_DELIMITER;

/**
 * The builder for the serializers and deserializers for csv formats.
 */
public abstract class CsvFormatBuilder<T extends CsvFormatBuilder> extends TextFormatBuilder<T> {

    protected char delimiter = DEFAULT_DELIMITER;

    public CsvFormatBuilder(RowFormatInfo rowFormatInfo) {
        super(rowFormatInfo);
    }

    @SuppressWarnings("unchecked")
    public T setDelimiter(Character delimiter) {
        this.delimiter = delimiter;
        return (T) this;
    }

    @SuppressWarnings("unchecked")
    @Override
    public T configure(DescriptorProperties descriptorProperties) {
        super.configure(descriptorProperties);

        descriptorProperties.getOptionalCharacter(FORMAT_DELIMITER)
                .ifPresent(this::setDelimiter);

        return (T) this;
    }
}
